import React, { ChangeEvent, FC, MouseEvent, useState } from 'react';
import {
  Collapse,
  IconButton,
  InputAdornment,
  TextField,
  Tooltip,
} from '@mui/material';
import { useMRT } from '../useMRT';
import { useAsyncDebounce } from 'react-table';
import { MRT_FilterTypeMenu } from '../menus/MRT_FilterTypeMenu';

interface Props {}

export const MRT_SearchTextField: FC<Props> = () => {
  const {
    icons: { SearchIcon, CloseIcon },
    idPrefix,
    localization,
    muiSearchTextFieldProps,
    onGlobalFilterChange,
    tableInstance,
  } = useMRT();

  const [anchorEl, setAnchorEl] = useState<null | HTMLElement>(null);
  const [searchValue, setSearchValue] = useState('');

  const handleChange = useAsyncDebounce(
    (event: ChangeEvent<HTMLInputElement>) => {
      tableInstance.setGlobalFilter(event.target.value ?? undefined);
      onGlobalFilterChange?.(event);
    },
    200,
  );

  const handleGlobalFilterMenuOpen = (event: MouseEvent<HTMLElement>) => {
    setAnchorEl(event.currentTarget);
  };

  const handleClear = () => {
    setSearchValue('');
    tableInstance.setGlobalFilter(undefined);
  };

  return (
    <Collapse in={tableInstance.state.showSearch} orientation="horizontal">
      <TextField
        id={`mrt-${idPrefix}-search-text-field`}
        placeholder={localization.search}
        onChange={(event: ChangeEvent<HTMLInputElement>) => {
          setSearchValue(event.target.value);
          handleChange(event);
        }}
        value={searchValue ?? ''}
        variant="standard"
        InputProps={{
          startAdornment: (
            <InputAdornment position="start">
              <Tooltip arrow title={localization.changeSearchMode}>
                <span>
                  <IconButton
                    aria-label={localization.changeSearchMode}
                    onClick={handleGlobalFilterMenuOpen}
                    size="small"
                    sx={{ height: '1.75rem', width: '1.75rem' }}
                  >
                    <SearchIcon fontSize="small" />
                  </IconButton>
                </span>
              </Tooltip>
            </InputAdornment>
          ),
          endAdornment: (
            <InputAdornment position="end">
              <IconButton
                aria-label={localization.clearSearch}
                disabled={searchValue?.length === 0}
                onClick={handleClear}
                size="small"
                title={localization.clearSearch}
              >
                <CloseIcon fontSize="small" />
              </IconButton>
            </InputAdornment>
          ),
        }}
        {...muiSearchTextFieldProps}
        sx={{ justifySelf: 'end', ...muiSearchTextFieldProps?.sx }}
      />
      <MRT_FilterTypeMenu anchorEl={anchorEl} setAnchorEl={setAnchorEl} />
    </Collapse>
  );
};
